@@ -3,11 +3,10 @@
     tests.test_config
     ~~~~~~~~~~~~~~~~~
 
-    :copyright: (c) 2015 by the Flask Team, see AUTHORS for more details.
+    :copyright: © 2010 by the Pallets team.
     :license: BSD, see LICENSE for more details.
 """
 
-
 from datetime import timedelta
 import os
 import textwrap
@@ -19,11 +18,11 @@ import pytest
 
 # config keys used for the TestConfig
 TEST_KEY = 'foo'
-SECRET_KEY = 'devkey'
+SECRET_KEY = 'config'
 
 
 def common_object_test(app):
-    assert app.secret_key == 'devkey'
+    assert app.secret_key == 'config'
     assert app.config['TEST_KEY'] == 'foo'
     assert 'TestConfig' not in app.config
 
@@ -50,21 +49,21 @@ def test_config_from_json():
 def test_config_from_mapping():
     app = flask.Flask(__name__)
     app.config.from_mapping({
-        'SECRET_KEY': 'devkey',
+        'SECRET_KEY': 'config',
         'TEST_KEY': 'foo'
     })
     common_object_test(app)
 
     app = flask.Flask(__name__)
     app.config.from_mapping([
-        ('SECRET_KEY', 'devkey'),
+        ('SECRET_KEY', 'config'),
         ('TEST_KEY', 'foo')
     ])
     common_object_test(app)
 
     app = flask.Flask(__name__)
     app.config.from_mapping(
-        SECRET_KEY='devkey',
+        SECRET_KEY='config',
         TEST_KEY='foo'
     )
     common_object_test(app)
@@ -81,7 +80,8 @@ def test_config_from_class():
         TEST_KEY = 'foo'
 
     class Test(Base):
-        SECRET_KEY = 'devkey'
+        SECRET_KEY = 'config'
+
     app = flask.Flask(__name__)
     app.config.from_object(Test)
     common_object_test(app)
